Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2011-01-09 18:12:08 +0300
committerCampbell Barton <ideasman42@gmail.com>2011-01-09 18:12:08 +0300
commit00b8c9e7eaef445be425f06111c91a92edf4406b (patch)
tree81437a6af43d74a44f9c467eeb58b0c6424446d7 /source/blender/blenlib/BLI_utildefines.h
parent9cb71d1159a1cd8aa110e195d42828f863cdd02a (diff)
rename BKE_assert() --> BLI_assert().
Diffstat (limited to 'source/blender/blenlib/BLI_utildefines.h')
-rw-r--r--source/blender/blenlib/BLI_utildefines.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/source/blender/blenlib/BLI_utildefines.h b/source/blender/blenlib/BLI_utildefines.h
index 468c146a65d..ccda9c17d43 100644
--- a/source/blender/blenlib/BLI_utildefines.h
+++ b/source/blender/blenlib/BLI_utildefines.h
@@ -181,7 +181,7 @@
#endif
/* BKE_assert(), default only to print
* for aborting need to define WITH_ASSERT_ABORT
*/
#if !defined NDEBUG
@@ -191,28 +191,28 @@
# define _dummy_abort() (void)0
# endif
# ifdef __GNUC__ /* just want to check if __func__ is available */
-# define BKE_assert(a) \
+# define BLI_assert(a) \
do { \
if (0 == (a)) { \
fprintf(stderr, \
- "BKE_assert failed: %s, %s(), %d at \'%s\'\n", \
+ "BLI_assert failed: %s, %s(), %d at \'%s\'\n", \
__FILE__, __func__, __LINE__, STRINGIFY(a)); \
_dummy_abort(); \
} \
} while (0)
# else
-# define BKE_assert(a) \
+# define BLI_assert(a) \
do { \
if (0 == (a)) { \
fprintf(stderr, \
- "BKE_assert failed: %s, %d at \'%s\'\n", \
+ "BLI_assert failed: %s, %d at \'%s\'\n", \
__FILE__, __LINE__, STRINGIFY(a)); \
_dummy_abort(); \
} \
} while (0)
# endif
#else
-# define BKE_assert(a) (void)0
+# define BLI_assert(a) (void)0
#endif
#endif // BLI_UTILDEFINES_H
@@ -181,7 +181,7 @@
#endif
-/* BKE_assert(), default only to print
+/* BLI_assert(), default only to print
* for aborting need to define WITH_ASSERT_ABORT
*/